((.venv) ) ~/ferdilegend $ def selam():
bash: syntax error near unexpected token `('
((.venv) ) ~/ferdilegend $     print("Selam kuzen! ferdilegend çalışıyor 🔥")
bash: syntax error near unexpected token `"Selam kuzen! ferdilegend çalışıyor 🔥"'
((.venv) ) ~/ferdilegend $
