from setuptools import setup, find_packages

setup(
    name="ferdilegend",
    version="0.1.0",
    description="FerdiLegend pip",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    author="Ferdi",
    packages=find_packages(),  # ferdilegend klasörünü otomatik bulur
    install_requires=[],
    python_requires=">=3.9",
    url="https://github.com/ferdissss/ferdilegend",
)
